@@ -5,36 +5,19 @@ import os
 import shutil
 from unittest.mock import patch
 import sys
+import pytest
 
 
-def setup_module(module):
-    global FILE_1
-    global FILE_2
-    global FILE_3
-    global EMPTY_FILE
-    global DIR
-    global PERM_DEN_DIR
-    global PERM_DEN_FILE
-    global DIR_2
-
-    DIR = 'test_dir'
-    DIR_2 = 'test_dir_2'
-    FILE_1 = os.path.join(DIR, 'test1.messtat')
-    FILE_2 = os.path.join(DIR, 'test2.messtat')
-    FILE_3 = os.path.join(DIR, 'test3.messtat')
-    EMPTY_FILE = os.path.join(DIR, 'empty.messtat')
-    PERM_DEN_DIR = os.path.join(DIR, 'not_write_dir')
-    PERM_DEN_FILE = os.path.join(DIR_2, 'perm_err.messtat')
-
-    os.mkdir(DIR)
-    os.mkdir(PERM_DEN_DIR)
-    os.mkdir(DIR_2)
-    os.chmod(PERM_DEN_DIR, 0)
-
-    with open(PERM_DEN_FILE, 'w'):
-        pass
-
-    os.chmod(PERM_DEN_FILE, 0)
+@pytest.fixture(scope='module')
+def test_dir(tmpdir_factory):
+    dir_path = tmpdir_factory.mktemp('test_dir')
+    dir_path_2 = tmpdir_factory.mktemp('test_dir_2')
+    empty_path = tmpdir_factory.mktemp(' ')
+    file_1 = dir_path.join('test1.messtat')
+    file_2 = dir_path.join('test2.messtat')
+    file_3 = dir_path.join('test3.messtat')
+    empty_file = dir_path.join('test4_empty.messtat')
+    perm_denied = dir_path.join('test5_permden.messtat')
 
     text1 = 'package-1: 51,836720J	dram: 8,094236J\n' \
             'package-0: 68,425240J	dram: 8,174866J\n' \
@@ -80,28 +63,16 @@ def setup_module(module):
             'package-0: 177,684237J	dram: 14,618844J\n' \
             '50,06	0,00	0,00	0,00	0,00\n'
 
-    with open(FILE_1, 'w') as file:
-        file.write(text1)
+    file_1.write(text1)
+    file_2.write(text2)
+    file_3.write(text3)
+    empty_file.write('')
+    perm_denied.write('')
+    perm_denied.chmod(0)
 
-    with open(FILE_2, 'w') as file:
-        file.write(text2)
+    return dir_path, dir_path_2, empty_path, file_1, file_2, file_3, empty_file, perm_denied
 
-    with open(FILE_3, 'w') as file:
-        file.write(text3)
-
-    with open(EMPTY_FILE, 'w'):
-        pass
-
-
-def teardown_module(module):
-    os.chmod(PERM_DEN_DIR, 777)
-    os.chmod(PERM_DEN_FILE, 777)
-    shutil.rmtree(DIR)
-    shutil.rmtree(DIR_2)
-    os.remove('messtat_.spliter')
-
-
-def test_parser_for_messtatfile():
+def test_parser_for_messtatfile(test_dir):
     expect_1 = (0, [51.83672, 68.42524, 42.836865, 56.918372])
     expect_2 = (0, [43.681163, 52.444812, 42.841015, 56.222818, 167.287719, 159.156453])
     expect_3 = (0, [198.265667, 178.879059, 198.888102, 178.416352, 198.785196, 179.179901,
@@ -109,22 +80,22 @@ def test_parser_for_messtatfile():
                 200.303259, 181.665368, 200.515051, 185.86012, 198.124188, 177.684237])
     expect_4 = (0, [])
 
-    path_5 = PERM_DEN_FILE
-    path_6 = os.path.join('test', 'test', 'test', 'test_write_to_file_1.messtat')
+    dir_path, dir_path_2, empty_path, file_1, file_2, file_3, empty_file, perm_denied = test_dir
 
-    expect_5 = (-1, "[Errno 13] Permission denied: 'test_dir_2/perm_err.messtat'")
-    expect_6 = (-1, "[Errno 2] No such file or directory: "
-                    "'test/test/test/test_write_to_file_1.messtat'")
+    not_exist = os.path.join('/', 'not_exixst.messtat')
+    expect_5 = (-1, "[Errno 13] Permission denied: '%s'" % perm_denied)
+    expect_6 = (-1, "[Errno 2] No such file or directory: '%s'" % not_exist)
 
-    assert split.parser_for_messtatfile(FILE_1) == expect_1
-    assert split.parser_for_messtatfile(FILE_2) == expect_2
-    assert split.parser_for_messtatfile(FILE_3) == expect_3
-    assert split.parser_for_messtatfile(EMPTY_FILE) == expect_4
-    assert split.parser_for_messtatfile(path_5) == expect_5
-    assert split.parser_for_messtatfile(path_6) == expect_6
+    assert split.parser_for_messtatfile(file_1) == expect_1
+    assert split.parser_for_messtatfile(file_2) == expect_2
+    assert split.parser_for_messtatfile(file_3) == expect_3
+    assert split.parser_for_messtatfile(empty_file) == expect_4
+    assert split.parser_for_messtatfile(perm_denied) == expect_5
+    assert split.parser_for_messtatfile(not_exist) == expect_6
 
+def test_counting_values(test_dir):
+    dir_path, dir_path_2, empty_path, file_1, file_2, file_3, empty_file, perm_denied = test_dir
 
-def test_counting_values():
     expect_1 = {
         'Min': 42.836865,
         'Max': 68.42524,
@@ -155,20 +126,25 @@ def test_counting_values():
     assert split.counting_values(data_empty) == expect_empty
     assert split.counting_values(data_incorrect) == expect_incorrect
 
-    _, data = split.parser_for_messtatfile(FILE_1)
+    assert split.counting_values(data_empty) == expect_empty
+    assert split.counting_values(data_incorrect) == expect_incorrect
+
+    _, data = split.parser_for_messtatfile(file_1)
     assert split.counting_values(data) == (exp_err, expect_1)
 
-    _, data = split.parser_for_messtatfile(FILE_2)
+    _, data = split.parser_for_messtatfile(file_2)
     assert split.counting_values(data) == (exp_err, expect_2)
 
-    _, data = split.parser_for_messtatfile(FILE_3)
+    _, data = split.parser_for_messtatfile(file_3)
     assert split.counting_values(data) == (exp_err, expect_3)
 
-    _, data = split.parser_for_messtatfile(EMPTY_FILE)
+    _, data = split.parser_for_messtatfile(empty_file)
     assert split.counting_values(data) == (exp_err, expect_4)
 
 
-def test_splitres():
+def test_splitres(test_dir):
+    dir_path, dir_path_2, empty_path, file_1, file_2, file_3, empty_file, perm_denied = test_dir
+
     expect_1 = {
         'Min': 42.836865,
         'Max': 68.42524,
@@ -192,35 +168,39 @@ def test_splitres():
 
     with patch('os.path.isdir', return_value=False), \
          patch('builtins.print') as mm:
-        split.splitres('not exist file', DIR)
+        split.splitres('not exist file', test_dir)
 
         mm.assert_called_once_with('File isn\'t exist!', file=sys.stderr)
 
-    assert split.splitres(FILE_1, DIR) == [expect_1]
-    assert split.splitres(FILE_2, DIR) == [expect_2]
-    assert split.splitres(FILE_3, DIR) == [expect_3]
+    assert split.splitres(file_1, dir_path) == [expect_1]
+    assert split.splitres(file_2, dir_path) == [expect_2]
+    assert split.splitres(file_3, dir_path) == [expect_3]
+
+    with patch('builtins.print') as mm:
+        data = split.splitres(dir_path, dir_path)
 
-    data = split.splitres(DIR, DIR)
     for item in data:
         assert item in expect
 
+def test_splitres_error(test_dir):
+    dir_path, dir_path_2, empty_path, file_1, file_2, file_3, empty_file, perm_denied = test_dir
 
-def test_splitres_error():
-    file_path_1 = EMPTY_FILE
+    file_path_1 = empty_file
     result_dir_1 = os.path.join('test', 'test', 'test')
     expect_1 = None
 
-    file_path_2 = DIR_2
-    result_dir_2 = DIR
+    file_path_2 = dir_path_2
+    result_dir_2 = dir_path
     expect_2 = []
 
     assert split.splitres(file_path_1, result_dir_1) == expect_1
     assert split.splitres(file_path_2, result_dir_2) == expect_2
 
+def test_check_exist_dir(test_dir):
+    dir_path, dir_path_2, empty_path, file_1, file_2, file_3, empty_file, perm_denied = test_dir
 
-def test_check_exist_dir():
-    exist_dir = DIR
-    not_exist_dir = os.path.join(DIR, 'test')
+    exist_dir = str(dir_path)
+    not_exist_dir = os.path.join(dir_path, 'test')
     incorrect_value = 123
     empty_string = ''
     perm_err = '/perm_err'
@@ -237,8 +217,9 @@ def test_check_exist_dir():
     assert split.check_exist_dir(empty_string) == expect_4
     assert split.check_exist_dir(perm_err) == expect_5
 
+def test_write_to_file(test_dir):
+    dir_path, dir_path_2, empty_path, file_1, file_2, file_3, empty_file, perm_denied = test_dir
 
-def test_write_to_file():
     results_1_incorrect = [12, 123, 23]
     path_1 = 'file.txt'
     expect_1 = (-1, 'Incorrect type results')
@@ -253,7 +234,7 @@ def test_write_to_file():
     expect_2 = (-1, 'Incorrect type path')
 
     results_3_empty = {}
-    path_3 = os.path.join(DIR, 'test_write_to_file_1.messtat')
+    path_3 = os.path.join(dir_path, 'test_write_to_file_1.messtat')
     expect_3 = (0, '')
 
     results_4 = {
@@ -262,7 +243,7 @@ def test_write_to_file():
         'Mean': 189.37092438888888,
         'Sum': 3408.676639,
         }
-    path_4_empty = ''
+    path_4_empty = os.path.join(empty_path, 'test_write_to_file_1.messtat')
     expect_4 = (0, '')
 
     results_5 = {
@@ -271,7 +252,7 @@ def test_write_to_file():
         'Mean': 189.37092438888888,
         'Sum': 3408.676639,
     }
-    path_5 = os.path.join(DIR, 'test_write_to_file_1.messtat')
+    path_5 = os.path.join(dir_path, 'test_write_to_file_1.messtat')
     expect_5 = (0, '')
 
     results_6 = {
@@ -301,16 +282,17 @@ def test_write_to_file():
     assert split.write_to_file(path_6, results_6) == expect_6
     assert split.write_to_file(path_7, results_7) == expect_7
 
+def test_splitres_for_file(test_dir):
+    dir_path, dir_path_2, empty_path, file_1, file_2, file_3, empty_file, perm_denied = test_dir
 
-def test_splitres_for_file():
-    path_1 = PERM_DEN_FILE
-    result_dir_1 = DIR
-    expect_1 = (-1, "[Errno 13] Permission denied: 'test_dir_2/perm_err.messtat'")
+    path_1 = perm_denied
+    result_dir_1 = dir_path
+    expect_1 = (-1, "[Errno 13] Permission denied: '"+str(perm_denied)+"'")
 
-    path_2 = EMPTY_FILE
+    path_2 = empty_file
     result_dir_2 = os.path.join('test', 'test', 'test')
     expect_2 = (-1, "[Errno 2] No such file or directory: "
-                    "'test/test/test/messtat_empty.messtat.spliter'")
+                    "'test/test/test/messtat_test4_empty.messtat.spliter'")
 
     assert split.splitres_for_file(path_1, result_dir_1) == expect_1
     assert split.splitres_for_file(path_2, result_dir_2) == expect_2
